/*****************************************************************************
 *                                                                           *
 * Copyright 2006 Timothy F Clarke (timothyclarke@gmail.com)                 *
 *                                                                           *
 * This work is licensed under the Creative Commons Attribution License.     *
 *                                                                           *
 * To view a copy of this license, visit                                     *
 * http://creativecommons.org/licenses/by/2.0 or send a letter to Creative   *
 * Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.          *
 *                                                                           *
 * You are free:                                                             *
 *     - to copy, distribute, display, and perform the work                  *
 *     - to make derivative works                                            *
 *     - to make commercial use of the work                                  *
 * Under the following conditions:                                           *
 *     - Attribution. You must give the original author credit.              *
 *     - For any reuse or distribution, you must make clear to others the    *
 *           license terms of this work.                                     *
 *     - Any of these conditions can be waived if you get permission from    *
 *           the copyright holder.                                           *
 * Your fair use and other rights are in no way affected by the above.       *
 *                                                                           *
 * Notification of use of this work would be appreciated but is in no way    *
 * mandatory.                                                                *
 *                                                                           *
 ****************************************************************************/



/*
 * Return a random value according to the rule i_average +/- i_variance.
 *
 * i_rnd_seed: an initialized random number seed
 * i_average: the approximate value to return
 * i_variance: the approximation variance of the returned value
 */
#macro Random( i_rnd_seed, i_average, i_variance )
    ( i_average +
        (( 0.5 - rand( i_rnd_seed )) * ( i_variance * 2 )))
#end


/*
 * Return a random whole value according to the rule i_average +/- i_variance.
 *
 * i_rnd_seed: an initialized random number seed
 * i_average: the approximate value to return
 * i_variance: the approximation variance of the returned value
 */
#macro FloorRandom( i_rnd_seed, i_average, i_variance )
    floor( Random( i_rnd_seed, i_average, i_variance ))
#end


/*
 * Return a random value between zero and one hundred inclusive.
 *
 * i_rnd_seed: an initialized random number seed
 */
#macro Random_Percentile( i_rnd_seed )
    Random( i_rnd_seed, 50, 50 )
#end


/*
 * Convert from degrees to radians.
 *
 * i_degrees: the value to convert
 */
#macro Radians( i_degrees )
    (( 2 * pi ) * ( i_degrees / 360 ))
#end


/*
 * Convert from polar coordinates to rectangular coordinates.
 *
 * i_radius: the radius of the polar coordinates to convert
 * i_radians: the angle in radians of the polar coordinates to convert
 */
#macro RectangularCoordinates( i_radius, i_radians )
    <( i_radius * cos( i_radians )), ( i_radius * sin( i_radians )), 0>
#end
