/*****************************************************************************
 *                                                                           *
 * Copyright 2006 Timothy F Clarke (timothyclarke@gmail.com)                 *
 *                                                                           *
 * This work is licensed under the Creative Commons Attribution License.     *
 *                                                                           *
 * To view a copy of this license, visit                                     *
 * http://creativecommons.org/licenses/by/2.0 or send a letter to Creative   *
 * Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.          *
 *                                                                           *
 * You are free:                                                             *
 *     - to copy, distribute, display, and perform the work                  *
 *     - to make derivative works                                            *
 *     - to make commercial use of the work                                  *
 * Under the following conditions:                                           *
 *     - Attribution. You must give the original author credit.              *
 *     - For any reuse or distribution, you must make clear to others the    *
 *           license terms of this work.                                     *
 *     - Any of these conditions can be waived if you get permission from    *
 *           the copyright holder.                                           *
 * Your fair use and other rights are in no way affected by the above.       *
 *                                                                           *
 * Notification of use of this work would be appreciated but is in no way    *
 * mandatory.                                                                *
 *                                                                           *
 ****************************************************************************/



#include "colors.inc"
#include "glass.inc"
#include "metals.inc"
#include "textures.inc"



#declare TESTING = false;



#ifdef ( TESTING )
    #if (TESTING )
        #declare RENDER_INFLORESCENCE = false;
        #declare RENDER_SPIKELETS = false;
        #declare RENDER_LEAVES = false;
    #end
#end

#include "meadow_foxtail.inc"



global_settings
{
    max_trace_level 6
}

sky_sphere
{
    pigment
    {
        White
    }
}

light_source
{
    <-2000, 4000, -3000>
    White
}

light_source
{
    <2000, 4000, -3000>
    White
}

plane
{
    y 0
    texture { T_Chrome_5E }
}



#macro MakeSphere( i_sphere_radius, i_texture, i_location )
    sphere
    {
        <0, i_sphere_radius, 0> i_sphere_radius
        texture
        {
            i_texture
        }

        translate i_location
        scale <1, 0.3, 1>
    }
#end


#macro MakeSpheres()
    #local COMMON_TEXTURE =
        texture { pigment { rgbf <0.2, 0.2, 0.5, 1> } finish { Glass_Finish }}
    #local BLACK_SHEEP_TEXTURE =
        texture { pigment { rgbf <0.7, 0.2, 0.2, 1> } finish { Glass_Finish }}

    #local sphere_radius = 3;

    MakeSphere( sphere_radius, COMMON_TEXTURE, <11, 0, -13> )
    MakeSphere( sphere_radius, COMMON_TEXTURE, <11, 0, -22> )
    MakeSphere( sphere_radius, COMMON_TEXTURE, <40, 0, -25> )
    MakeSphere( sphere_radius, COMMON_TEXTURE, <35, 0, -17> )
    MakeSphere( sphere_radius, COMMON_TEXTURE, <47, 0, 0> )
    MakeSphere( sphere_radius, COMMON_TEXTURE, <65, 0, -30> )
    MakeSphere( sphere_radius, BLACK_SHEEP_TEXTURE, <20, 0, -22> )
#end


#macro MakeScene()
    #local NUM_MEADOW_FOXTAILS = 12;

    #local Z_ROTATION = 8.5;
    #local Z_ROTATION_VARIANCE = 5;

    #local PLANTING_WIDTH = 5;
    #local BURIED_DEPTH = -20;
    #local PLANTING_DEPTH = 5;

    #local rnd_seed = seed( 0 );

    union
    {
        #local meadow_foxtail_idx = 0;

        #local Y_ROTATION = -112.5;
        #local Y_ROTATION_VARIANCE = 42.5;

        #while ( meadow_foxtail_idx < NUM_MEADOW_FOXTAILS / 2 )
            object
            {
                MakeMeadowFoxtail( rnd_seed )

                rotate <0, 0,
                    -( Random( rnd_seed, Z_ROTATION, Z_ROTATION_VARIANCE ))>
                rotate <0,
                    Random( rnd_seed, Y_ROTATION, Y_ROTATION_VARIANCE ), 0>
                translate <(( rand( rnd_seed ) - 0.5 ) * PLANTING_WIDTH ),
                    BURIED_DEPTH,
                    (( rand( rnd_seed ) - 0.5 ) * PLANTING_DEPTH )>
            }

            #local meadow_foxtail_idx = ( meadow_foxtail_idx + 1 );
        #end

        #local Y_ROTATION = -67.5;
        #local Y_ROTATION_VARIANCE = 42.5;

        #while ( meadow_foxtail_idx < NUM_MEADOW_FOXTAILS )
            object
            {
                MakeMeadowFoxtail( rnd_seed )

                rotate <0, 0,
                    -( Random( rnd_seed, Z_ROTATION, Z_ROTATION_VARIANCE ))>
                rotate <0,
                    Random( rnd_seed, Y_ROTATION, Y_ROTATION_VARIANCE ), 0>
                translate <(( rand( rnd_seed ) - 0.5 ) * PLANTING_WIDTH ),
                    BURIED_DEPTH,
                    (( rand( rnd_seed ) - 0.5 ) * PLANTING_DEPTH )>
            }

            #local meadow_foxtail_idx = ( meadow_foxtail_idx + 1 );
        #end
    }

    MakeSpheres()

    camera
    {
        location <30, 30, -115>
        look_at <30, 30, 0>
    }
#end



MakeScene()
